@@ -1,11 +1,12 @@
 import os
+from pathlib import Path
 from typing import List
 
 from prospector.message import Message
 from prospector.suppression import get_suppressions
 
 
-def filter_messages(relative_filepaths: List[str], root: str, messages: List[Message]) -> List[Message]:
+def filter_messages(filepaths: List[Path], messages: List[Message]) -> List[Message]:
     """
     This method post-processes all messages output by all tools, in order to filter
     out any based on the overall output.
@@ -24,7 +25,7 @@ def filter_messages(relative_filepaths: List[str], root: str, messages: List[Mes
     This method uses the information about suppressed messages from pylint to
     squash the unwanted redundant error from pyflakes and frosted.
     """
-    paths_to_ignore, lines_to_ignore, messages_to_ignore = get_suppressions(relative_filepaths, root, messages)
+    paths_to_ignore, lines_to_ignore, messages_to_ignore = get_suppressions(filepaths, messages)
 
     filtered = []
     for message in messages:
